/**
 * File for terminal logic.
 *
 * Note that all of these are in relation to the line the cursor is currently on.
 */

// User Import Headers.
#ifndef user_headers
    #define user_headers
    #include "simulate_loads.h"
    #include "structs.h"
    #include "terminal_commands.h"
#endif


/**
 * Move to start of current line.
 * Note that this does not erase, but any output will write over the respective character.
 */
void terminal_line_start() {
    printf("\r");
}


/**
 * Move to end of current line.
 * Note that th is does appear to erase, from where cursor was, up until end of line.
 */
void terminal_line_end() {
    printf("\033[K");
}


/**
 * Moves cursor up one single line.
 * Cursor will stay at the current column place.
 */
void terminal_line_up() {
    printf("\033[A");
}


/**
 * Moves cursor down one single line.
 * Cursor will stay at the current column place.
 */
void terminal_line_down() {
    printf("\033[B");
}


/**
 * Moves curor left by one place.
 */
void terminal_arrow_left() {
    printf("\033[D");
}


/**
 * Moves cursor right by one place.
 */
void terminal_arrow_right() {
    printf("\033[C");
}


/**
 * Erases entire line cursor is on, and moves cursor back to start of line.
 */
void terminal_line_erase() {
    printf("\33[2K");
    terminal_line_start();
}


/**
 * Prints full Lorem Ipsum paragraph, with no break characters.
 */
void print_lorem_ipsum_paragraph() {
    printf("Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque tristique lacus vitae pharetra"
        "lacinia. Cras eu odio eros. Aliquam erat volutpat. Pellentesque habitant morbi tristique senectus et netus "
        "et malesuada fames ac turpis egestas. Mauris neque lacus, tristique eu arcu vel, auctor vehicula sapien. "
        "Cras blandit pretium aliquam. Integer malesuada, purus eget interdum placerat, est ipsum auctor lorem, quis"
        " mattis magna libero in neque. Morbi eget nunc lobortis, venenatis purus ac, mollis diam.");
}


/**
 * Prints full Lorem Ipsum paragraph, with each sentence on its own line.
 */
void print_lorem_ipsum_lines() {
    printf("Lorem ipsum dolor sit amet, consectetur adipiscing elit.\n");
    printf("Pellentesque tristique lacus vitae pharetra lacinia.\n");
    printf("Cras eu odio eros.\n");
    printf("Aliquam erat volutpat.\n");
    printf("Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas.\n");
    printf("Mauris neque lacus, tristique eu arcu vel, auctor vehicula sapien.\n");
    printf("Cras blandit pretium aliquam.\n");
    printf("Integer malesuada, purus eget interdum placerat, est ipsum auctor lorem, quis mattis magna libero in neque.\n");
    printf("Morbi eget nunc lobortis, venenatis purus ac, mollis diam.\n");
}
